@@ -1,8 +1,7 @@
 from typing_extensions import Literal, get_args as literal_args
 from typing import Tuple
 
-f_glb_method = Literal['auto', 'pointwise', 'GMeet', 'GMeet+', 'DMeet+',
-                       'JMeet', 'CMeet',]
+f_glb_method = Literal['auto', 'GMeet', 'GMeet+', 'DMeet+', 'JMeet', 'CMeet',]
 f_glb_methods: Tuple[str] = literal_args(f_glb_method)
 
 random_poset_method = Literal['auto', 'p_threshold']
